pub trait FromB64ContentFormat { }Expand description
A marker trait for content formats that can be converted from B64.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait FromB64ContentFormat { }A marker trait for content formats that can be converted from B64.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".